==> jAddo___2022-12-16_03-20-22.zip: about.php <==
<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="utf-8">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<title>ORV HeadQuarters - About Us</title>
	<meta name="description" content="ATV & SxS performance shop that offers customization, upgrades along with your everyday maintenance! 42 Union Street, Smiths Falls, ON, Canada K7A 5C4.">

	<!-- Fonts -->
	<link rel="preconnect" href="https://fonts.googleapis.com">
	<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
	<link href="https://fonts.googleapis.com/css2?family=Bebas+Neue&display=swap" rel="stylesheet">
	<link rel="stylesheet" href="https://use.typekit.net/ymo0arc.css">
	<link rel="stylesheet" type="text/css" href="assets/font/proxima-nova.css">

	<!-- Bootstrap CSS -->
	<link rel="stylesheet" type="text/css" href="assets/bootstrap/css/bootstrap.min.css">


	<!-- ICONSAX ICONS -->
	<link rel="stylesheet" type="text/css" href="assets/iconsax/style.css">
	<!-- FONTAWESOME ICONS -->
	<link rel="stylesheet" type="text/css" href="assets/font-awesome/css/all.css">
	
	<!-- Bootstrap ICONS -->
	<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.9.1/font/bootstrap-icons.css">

	<!-- Swiper CSS -->
	<link rel="stylesheet" href="assets/swiper/swiper-bundle.min.css">

	<!-- Tom Select CSS -->
	<link rel="stylesheet" href="assets/tom-select/tom-select.css">

	<!-- Bootstrap Plus CSS -->
	<link rel="stylesheet" type="text/css" href="assets/css/bootstrap-plus.css">
	<!-- CSS -->
	<link rel="stylesheet" type="text/css" href="assets/css/style.css">

</head>
<body class="bg-noise bg-dark text-white">
	<header>
		<a href="account.html" class="d-block d-lg-none bg-gradient-dark border-bottom border-1 border-white border-opacity-50 rounded-bottom text-primary text-md text-600 lh-sm text-center text-decoration-none p-4">
			<i class="bi bi-arrow-left me-2"></i>
			BACK TO MY ACCOUNT
		</a>
		<?php include './src/navbar.php';?>			
	</header>

	<main>
        <section class="section-about-us pt-3 mt-lg-5">   
            <div class="container"> 
                <div class="row justify-content-center mb-5 pb-4 pb-lg-5">   
                    <div class="col-sm-10 col-md-10 col-lg-12 col-xl-8 text-center mb-5"> 
                        <h1 class="headline-2 text-800 lh-1 text-uppercase mb-3">about us</h1>
                        <p class="text-xs lh-1_1 mb-md-4 mb-lg-3 mb-xl-0 mb-xxl-3 ">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.</p>
                        
                    </div>
                    <div class="col-12 col-md-10 col-lg-12 position-relative mb-2 mb-lg-0 mb-xl-2">
                        <img src="assets/images/about-company/ovr-showroom.png" alt="ORV showroom" class="w-100 rounded-3 object-fit-cover" height="508">
                        <p class="text-center text-lg-end text-xs lh-1 text-500 position-absolute bottom-0 end-0 me-lg-4 mb-3 px-3 img-desctiption">
                            Our showroom / warehouse. 
                            <span class="d-block d-lg-inline-block">
                                Feel free to visit us 
                                <a href="#footer-contact" class="text-700 text-decoration-none text-white">here!</a>  
                            </span>                          
                        </p>
                    </div>
                </div>
                <div class="row mb-5 pb-xl-5 justify-content-center justify-content-lg-between">   
                    <div class="col-12 col-md-10 col-lg-12 col-xl-6 col-xxl-5 text-center text-xl-start d-flex flex-column order-1 mb-5 mb-lg-4 mb-xl-auto">    
                        <h2 class="headline-2 lh-1 text-800 text-uppercase mb-4">15 YEARS OF EXPERIENCE</h2>
                        <p class="text-xs lh-1_1 mb-2 mb-lg-0">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magincididunt ut labore et dolore mag na aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut ullamco laboris nisi. </p>
						
						<!-- <div class="row align-items-center mb-5 mb-xl-0 justify-content-center">
							<div class="col-8 col-lg-5 col-xl-12">
								<h4 class="headline-4 lh-1 text-700 mb-5 mb-lg-0 mb-xl-4 pb-2 pb-lg-0 pb-xl-2">Certified ATVs part reseller</h4>
							</div>
							<div class="col-12 col-md-8 col-lg-7 col-xl-12 d-flex justify-content-lg-between justify-content-center flex-wrap">
								<img src="assets/images/Logo/logolpsum.png" alt="logo" width="205" class="mb-5 mb-lg-0">
								<img src="assets/images/Logo/logolpsum-1.png" alt="logo" width="205" class="">
								
							</div>
						</div> -->
					</div> 
					<div class="col-12 col-md-8 col-lg-12 col-xl-6 col-xxl-5 order-3 order-lg-2 order-xl-3 m-neg-md mb-lg-5 mb-xl-0">
						<div class="row align-items-center text-center text-xl-start">
							<div class="col-12 col-lg-5 col-xl-12">
								<h4 class="headline-4 lh-1 text-700 mb-5 mb-lg-0 mb-xl-4 pb-2 pb-lg-0 pb-xl-2">Certified ATVs part reseller</h4>
							</div>
							<div class="col-12 col-lg-7 col-xl-12 atv-logos d-flex flex-column flex-lg-row justify-content-lg-between justify-content-center flex-wrap">
								<img src="assets/images/Logo/logolpsum.png" alt="logo" width="205" class="mb-5 mb-lg-0">
								<img src="assets/images/Logo/logolpsum-1.png" alt="logo" width="205" class="">
								
							</div>
						</div>
					</div>
                    <div class="col-12 col-md-10 col-lg-12 col-xl-6 order-2 mb-5 mb-lg-0">
						<div class="row justify-content-center">
							<div class="col-12 col-lg-6 col-xl-12 order-1">
								<div class="d-flex w-100 bg-black bg-opacity-30 border border-2 border-primary rounded-3 p-4_5 mb-4 align-items-center advantage-box">
									<img src="assets/images/Icon/about-quality.svg" alt="icon best quality" class="flex-shrink-0 me-3 me-sm-4 pe-md-2">
									<div>
										<h4 class="headline-4 lh-1 text-800 text-uppercase mb-2">BEST QUALITY PARTS</h4>
										<p class="text-xs lh-1_1 mb-0">Lorem ipsum dolor sit amet, consectetur adipiscing</p>
									</div>
								</div>
								
							</div>
							<div class="col-12 col-lg-8 col-xl-12 order-3 order-xl-2">
								<div class="d-flex w-100 bg-black bg-opacity-30 border border-2 border-primary rounded-3 p-4_5 mb-4 align-items-center advantage-box">
									<img src="assets/images/Icon/about-chat.svg" alt="icon best quality" class="flex-shrink-0 me-3 me-sm-4 pe-md-2">
									<div>
										<h4 class="headline-4 lh-1 text-800 text-uppercase mb-2">OVER 7000 SATISFIED CUSTOMERS</h4>
										<p class="text-xs lh-1_1 mb-0">Lorem ipsum dolor sit amet, consectetur adipiscing</p>
									</div>
								</div>
							</div>
							<div class="col-12 col-lg-6 col-xl-12 order-2 order-xl-3">
								<div class="d-flex w-100 bg-black bg-opacity-30 border border-2 border-primary rounded-3 mb-4 p-4_5 mb-xl-0 align-items-center advantage-box">
									<img src="assets/images/Icon/about-fast-delivery.svg" alt="icon best quality" class="flex-shrink-0 me-3 me-sm-4 pe-md-2">
									<div>
										<h4 class="headline-4 lh-1 text-800 text-uppercase mb-2">QUICK DELIVERY TIME</h4>
										<p class="text-xs lh-1_1 mb-0">Lorem ipsum dolor sit amet, consectetur adipiscing</p>
									</div>
								</div>
							</div>
						</div>  
                    </div>
                </div>
                <div class="row pt-xl-4 mb-7 pb-5 pb-xxl-0 d-none d-lg-flex">
                    <div class="col-6">
                        <img src="assets/images/about-company/our-story.png" alt="our story orv headquorters" class="img-fluid h-100">
                    </div>
                    <div class="col-6">
                        <div class="d-flex flex-column justify-content-center h-100">
                            <h2 class="headline-2 lh-1 text-800 text-uppercase mb">OUR STORY</h2>
                            <p class="text-xs lh-1_1 mb-4">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi.</p>
                            <button class="btn btn-center btn-primary align-self-start">BROWSE OUR PRODUCRS</button>
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <?php include './src/section-browse.php'; ?>

		<section class="section-contact-form bg-black-pearl pt-5">
            <div class="container">
                <div class="row justify-content-center pt-5 text-center text-lg-start">
                    <div class="col-12 col-md-10">   
                        <h2 class="headline-2 lh-1 text-800 text-uppercase mt-4 mb-5">GET IN TOUCH</h2>                        
                    </div>
                    <div class="col-12 col-md-10 col-lg-6 mb-8 mb-lg-0">
                        <h5 class="headline-5 lh-1 text-700 text-primary mb-2">Send us a message</h5>
                        <p class="text-xs lh-1_1 mb-4">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempo</p>
                        <form class="row contact-form">
                            <div class="col-12 col-lg-6 mb-4_5">
                                <input type="text" class="form-control form-control-gray form-control-sm" placeholder="Name" name="Name#required#reply_name">
                            </div>
                            <div class="col-12 col-lg-6 mb-4_5">
                                <input type="email" class="form-control form-control-gray form-control-sm" placeholder="Email Address" name="E-Mail_Address#required#href_email#reply_email">
                            </div>
                            <div class="col-12 col-lg-6 mb-4_5">
                                <input type="text" class="form-control form-control-gray form-control-sm" placeholder="Topic" name="Topic">
                            </div>
                            <div class="col-12 col-lg-6 mb-4_5">
                                <input type="text" class="form-control form-control-gray form-control-sm" placeholder="Phone Number" name="Phone_Number#format_phone#required#href_all">
                            </div>
                            <div class="col-12 mb-4_5">
                                <textarea name="Message" class="form-control form-control-gray" rows="4" placeholder="Message"></textarea>
							</div>
							<div class="col-12">
                                <button type="submit" class="btn btn-center btn-primary w-100">Send</button>
                            </div>
                        </form>
                    </div>
                    <div class="col-10 col-md-8 col-lg-4">
                        <div class="border-start border-white border-1 d-flex flex-column ps-3 ps-xl-4 h-100 footer-form-address">
                            <div class="mb-5 mb-lg-auto pb-4 pb-lg-0">
                                <h5 class="headline-5 lh-1 text-700 text-primary mb-2">Call Us</h5>
                                <p class="text-xs lh-1_1 mb-6 mb-lg-4">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed</p>
                                <a href="tel:+100000000" target="_blank" class="text-decoration-none text-primary d-flex flex-column flex-lg-row  align-items-center text-xs lh-1 text-600">
                                    <span class="rounded-circle bg-primary bg-opacity-10 boxSize-lg d-flex justify-content-center align-items-center me-4 flex-shrink-0 mb-4 mb-lg-0">
                                        <i class="icon-call1 text-primary text-md"></i>
                                    </span>
                                    +1 000 0000 0000
                                </a>
                            </div>
                            <div class="mb-lg-3">
                                <h5 class="headline-5 lh-1 text-700 text-primary mb-2">Visit Us</h5>
                                <p class="text-xs lh-1_1 mb-6 mb-lg-4">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed</p>
                                <a href="https://www.google.com/maps/dir/?api=1&amp;destination=15%2042+Union+St,+Smiths+Falls,+ON+K7A+5C4,+Kanada/@42.2333765,-64.4506748,3z/data=!3m1!4b1!4m9!4m8!1m1!4e1!1m5!1m1!1s0x4cd20f1ab62d332f:0x727f799eab9d5b3a!2m2!1d-76.0235129!2d44.9123302" target="_blank" class="text-decoration-none text-primary d-flex flex-column flex-lg-row align-items-center text-xs lh-1 text-600">
                                    <span class="rounded-circle bg-primary bg-opacity-10 boxSize-lg d-flex  justify-content-center align-items-center me-4 flex-shrink-0 mb-4 mb-lg-0">
                                        <i class="icon-location1 text-primary text-md"></i>
                                    </span>
                                    42 Union St, Smiths Falls <br>
                                    ON K7A 5C4, Canada
                                </a>
                            </div>
                        </div>
                    </div>
                </div>
			</div>
		</section>
    </main>	
    
	<?php include './src/footer.php';?>	
	<?php include './src/navbar-offcanvas-chat.php';?>
    <?php include './src/navbar-offcanvas-cart.php';?>
    <?php include './src/navbar-offcanvas-user-panel.php';?>
    <?php include './src/navbar-modal.php';?>

	<!-- Bootstrap JS -->	
	<script type="text/javascript" src="assets/bootstrap/js/bootstrap.bundle.min.js" async></script>	

	<!-- Tom Select JS -->
	<script src="https://cdn.jsdelivr.net/npm/tom-select@2.1.0/dist/js/tom-select.complete.min.js"></script>

	<!-- Swiper JS -->
	<script src="assets/swiper/swiper-bundle.min.js" defer></script>

	<!-- JS -->
	<script type="text/javascript" src="assets/js/calender.js" defer></script>
	<script type="text/javascript" src="assets/js/my-account-script.js" defer></script>
	<script type="text/javascript" src="assets/js/script.js" defer></script>
</body>
</html>

==> jAddo___2022-12-16_03-20-51.zip: about.php <==
<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="utf-8">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<title>ORV HeadQuarters - About Us</title>
	<meta name="description" content="ATV & SxS performance shop that offers customization, upgrades along with your everyday maintenance! 42 Union Street, Smiths Falls, ON, Canada K7A 5C4.">

	<!-- Fonts -->
	<link rel="preconnect" href="https://fonts.googleapis.com">
	<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
	<link href="https://fonts.googleapis.com/css2?family=Bebas+Neue&display=swap" rel="stylesheet">
	<link rel="stylesheet" href="https://use.typekit.net/ymo0arc.css">
	<link rel="stylesheet" type="text/css" href="assets/font/proxima-nova.css">

	<!-- Bootstrap CSS -->
	<link rel="stylesheet" type="text/css" href="assets/bootstrap/css/bootstrap.min.css">


	<!-- ICONSAX ICONS -->
	<link rel="stylesheet" type="text/css" href="assets/iconsax/style.css">
	<!-- FONTAWESOME ICONS -->
	<link rel="stylesheet" type="text/css" href="assets/font-awesome/css/all.css">
	
	<!-- Bootstrap ICONS -->
	<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.9.1/font/bootstrap-icons.css">

	<!-- Swiper CSS -->
	<link rel="stylesheet" href="assets/swiper/swiper-bundle.min.css">

	<!-- Tom Select CSS -->
	<link rel="stylesheet" href="assets/tom-select/tom-select.css">

	<!-- Bootstrap Plus CSS -->
	<link rel="stylesheet" type="text/css" href="assets/css/bootstrap-plus.css">
	<!-- CSS -->
	<link rel="stylesheet" type="text/css" href="assets/css/style.css">

</head>
<body class="bg-noise bg-dark text-white">
	<header>
		<a href="my-account.php" class="mobile-navbar d-block d-lg-none bg-gradient-dark border-bottom border-1 border-white border-opacity-50 rounded-bottom text-primary text-md text-600 lh-sm text-center text-decoration-none p-4">
			<i class="bi bi-arrow-left me-2"></i>
			BACK TO MY ACCOUNT
		</a>
		<?php include './src/navbar.php';?>			
	</header>

	<main>
        <section class="section-about-us pt-3 mt-lg-5">   
            <div class="container"> 
                <div class="row justify-content-center mb-5 pb-4 pb-lg-5">   
                    <div class="col-sm-10 col-md-10 col-lg-12 col-xl-8 text-center mb-5"> 
                        <h1 class="headline-2 text-800 lh-1 text-uppercase mb-3">about us</h1>
                        <p class="text-xs lh-1_1 mb-md-4 mb-lg-3 mb-xl-0 mb-xxl-3 ">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.</p>
                        
                    </div>
                    <div class="col-12 col-md-10 col-lg-12 position-relative mb-2 mb-lg-0 mb-xl-2">
                        <img src="assets/images/about-company/ovr-showroom.png" alt="ORV showroom" class="w-100 rounded-3 object-fit-cover" height="508">
                        <p class="text-center text-lg-end text-xs lh-1 text-500 position-absolute bottom-0 end-0 me-lg-4 mb-3 px-3 img-desctiption">
                            Our showroom / warehouse. 
                            <span class="d-block d-lg-inline-block">
                                Feel free to visit us 
                                <a href="#footer-contact" class="text-700 text-decoration-none text-white">here!</a>  
                            </span>                          
                        </p>
                    </div>
                </div>
                <div class="row mb-5 pb-xl-5 justify-content-center justify-content-lg-between">   
                    <div class="col-12 col-md-10 col-lg-12 col-xl-6 col-xxl-5 text-center text-xl-start d-flex flex-column order-1 mb-5 mb-lg-4 mb-xl-auto">    
                        <h2 class="headline-2 lh-1 text-800 text-uppercase mb-4">15 YEARS OF EXPERIENCE</h2>
                        <p class="text-xs lh-1_1 mb-2 mb-lg-0">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magincididunt ut labore et dolore mag na aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut ullamco laboris nisi. </p>
						
						<!-- <div class="row align-items-center mb-5 mb-xl-0 justify-content-center">
							<div class="col-8 col-lg-5 col-xl-12">
								<h4 class="headline-4 lh-1 text-700 mb-5 mb-lg-0 mb-xl-4 pb-2 pb-lg-0 pb-xl-2">Certified ATVs part reseller</h4>
							</div>
							<div class="col-12 col-md-8 col-lg-7 col-xl-12 d-flex justify-content-lg-between justify-content-center flex-wrap">
								<img src="assets/images/Logo/logolpsum.png" alt="logo" width="205" class="mb-5 mb-lg-0">
								<img src="assets/images/Logo/logolpsum-1.png" alt="logo" width="205" class="">
								
							</div>
						</div> -->
					</div> 
					<div class="col-12 col-md-8 col-lg-12 col-xl-6 col-xxl-5 order-3 order-lg-2 order-xl-3 m-neg-md mb-lg-5 mb-xl-0">
						<div class="row align-items-center text-center text-xl-start">
							<div class="col-12 col-lg-5 col-xl-12">
								<h4 class="headline-4 lh-1 text-700 mb-5 mb-lg-0 mb-xl-4 pb-2 pb-lg-0 pb-xl-2">Certified ATVs part reseller</h4>
							</div>
							<div class="col-12 col-lg-7 col-xl-12 atv-logos d-flex flex-column flex-lg-row justify-content-lg-between justify-content-center flex-wrap">
								<img src="assets/images/Logo/logolpsum.png" alt="logo" width="205" class="mb-5 mb-lg-0">
								<img src="assets/images/Logo/logolpsum-1.png" alt="logo" width="205" class="">
								
							</div>
						</div>
					</div>
                    <div class="col-12 col-md-10 col-lg-12 col-xl-6 order-2 mb-5 mb-lg-0">
						<div class="row justify-content-center">
							<div class="col-12 col-lg-6 col-xl-12 order-1">
								<div class="d-flex w-100 bg-black bg-opacity-30 border border-2 border-primary rounded-3 p-4_5 mb-4 align-items-center advantage-box">
									<img src="assets/images/Icon/about-quality.svg" alt="icon best quality" class="flex-shrink-0 me-3 me-sm-4 pe-md-2">
									<div>
										<h4 class="headline-4 lh-1 text-800 text-uppercase mb-2">BEST QUALITY PARTS</h4>
										<p class="text-xs lh-1_1 mb-0">Lorem ipsum dolor sit amet, consectetur adipiscing</p>
									</div>
								</div>
								
							</div>
							<div class="col-12 col-lg-8 col-xl-12 order-3 order-xl-2">
								<div class="d-flex w-100 bg-black bg-opacity-30 border border-2 border-primary rounded-3 p-4_5 mb-4 align-items-center advantage-box">
									<img src="assets/images/Icon/about-chat.svg" alt="icon best quality" class="flex-shrink-0 me-3 me-sm-4 pe-md-2">
									<div>
										<h4 class="headline-4 lh-1 text-800 text-uppercase mb-2">OVER 7000 SATISFIED CUSTOMERS</h4>
										<p class="text-xs lh-1_1 mb-0">Lorem ipsum dolor sit amet, consectetur adipiscing</p>
									</div>
								</div>
							</div>
							<div class="col-12 col-lg-6 col-xl-12 order-2 order-xl-3">
								<div class="d-flex w-100 bg-black bg-opacity-30 border border-2 border-primary rounded-3 mb-4 p-4_5 mb-xl-0 align-items-center advantage-box">
									<img src="assets/images/Icon/about-fast-delivery.svg" alt="icon best quality" class="flex-shrink-0 me-3 me-sm-4 pe-md-2">
									<div>
										<h4 class="headline-4 lh-1 text-800 text-uppercase mb-2">QUICK DELIVERY TIME</h4>
										<p class="text-xs lh-1_1 mb-0">Lorem ipsum dolor sit amet, consectetur adipiscing</p>
									</div>
								</div>
							</div>
						</div>  
                    </div>
                </div>
                <div class="row pt-xl-4 mb-7 pb-5 pb-xxl-0 d-none d-lg-flex">
                    <div class="col-6">
                        <img src="assets/images/about-company/our-story.png" alt="our story orv headquorters" class="img-fluid h-100">
                    </div>
                    <div class="col-6">
                        <div class="d-flex flex-column justify-content-center h-100">
                            <h2 class="headline-2 lh-1 text-800 text-uppercase mb">OUR STORY</h2>
                            <p class="text-xs lh-1_1 mb-4">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi.</p>
                            <button class="btn btn-center btn-primary align-self-start">BROWSE OUR PRODUCRS</button>
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <?php include './src/section-browse.php'; ?>

		<section class="section-contact-form bg-black-pearl pt-5">
            <div class="container">
                <div class="row justify-content-center pt-5 text-center text-lg-start">
                    <div class="col-12 col-md-10">   
                        <h2 class="headline-2 lh-1 text-800 text-uppercase mt-4 mb-5">GET IN TOUCH</h2>                        
                    </div>
                    <div class="col-12 col-md-10 col-lg-6 mb-8 mb-lg-0">
                        <h5 class="headline-5 lh-1 text-700 text-primary mb-2">Send us a message</h5>
                        <p class="text-xs lh-1_1 mb-4">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempo</p>
                        <form class="row contact-form">
                            <div class="col-12 col-lg-6 mb-4_5">
                                <input type="text" class="form-control form-control-gray form-control-sm" placeholder="Name" name="Name#required#reply_name">
                            </div>
                            <div class="col-12 col-lg-6 mb-4_5">
                                <input type="email" class="form-control form-control-gray form-control-sm" placeholder="Email Address" name="E-Mail_Address#required#href_email#reply_email">
                            </div>
                            <div class="col-12 col-lg-6 mb-4_5">
                                <input type="text" class="form-control form-control-gray form-control-sm" placeholder="Topic" name="Topic">
                            </div>
                            <div class="col-12 col-lg-6 mb-4_5">
                                <input type="text" class="form-control form-control-gray form-control-sm" placeholder="Phone Number" name="Phone_Number#format_phone#required#href_all">
                            </div>
                            <div class="col-12 mb-4_5">
                                <textarea name="Message" class="form-control form-control-gray" rows="4" placeholder="Message"></textarea>
							</div>
							<div class="col-12">
                                <button type="submit" class="btn btn-center btn-primary w-100">Send</button>
                            </div>
                        </form>
                    </div>
                    <div class="col-10 col-md-8 col-lg-4">
                        <div class="border-start border-white border-1 d-flex flex-column ps-3 ps-xl-4 h-100 footer-form-address">
                            <div class="mb-5 mb-lg-auto pb-4 pb-lg-0">
                                <h5 class="headline-5 lh-1 text-700 text-primary mb-2">Call Us</h5>
                                <p class="text-xs lh-1_1 mb-6 mb-lg-4">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed</p>
                                <a href="tel:+100000000" target="_blank" class="text-decoration-none text-primary d-flex flex-column flex-lg-row  align-items-center text-xs lh-1 text-600">
                                    <span class="rounded-circle bg-primary bg-opacity-10 boxSize-lg d-flex justify-content-center align-items-center me-4 flex-shrink-0 mb-4 mb-lg-0">
                                        <i class="icon-call1 text-primary text-md"></i>
                                    </span>
                                    +1 000 0000 0000
                                </a>
                            </div>
                            <div class="mb-lg-3">
                                <h5 class="headline-5 lh-1 text-700 text-primary mb-2">Visit Us</h5>
                                <p class="text-xs lh-1_1 mb-6 mb-lg-4">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed</p>
                                <a href="https://www.google.com/maps/dir/?api=1&amp;destination=15%2042+Union+St,+Smiths+Falls,+ON+K7A+5C4,+Kanada/@42.2333765,-64.4506748,3z/data=!3m1!4b1!4m9!4m8!1m1!4e1!1m5!1m1!1s0x4cd20f1ab62d332f:0x727f799eab9d5b3a!2m2!1d-76.0235129!2d44.9123302" target="_blank" class="text-decoration-none text-primary d-flex flex-column flex-lg-row align-items-center text-xs lh-1 text-600">
                                    <span class="rounded-circle bg-primary bg-opacity-10 boxSize-lg d-flex  justify-content-center align-items-center me-4 flex-shrink-0 mb-4 mb-lg-0">
                                        <i class="icon-location1 text-primary text-md"></i>
                                    </span>
                                    42 Union St, Smiths Falls <br>
                                    ON K7A 5C4, Canada
                                </a>
                            </div>
                        </div>
                    </div>
                </div>
			</div>
		</section>
    </main>	
    
	<?php include './src/footer.php';?>	
	<?php include './src/navbar-offcanvas-chat.php';?>
    <?php include './src/navbar-offcanvas-cart.php';?>
    <?php include './src/navbar-offcanvas-user-panel.php';?>
    <?php include './src/navbar-modal.php';?>

	<!-- Bootstrap JS -->	
	<script type="text/javascript" src="assets/bootstrap/js/bootstrap.bundle.min.js" async></script>	

	<!-- Tom Select JS -->
	<script src="https://cdn.jsdelivr.net/npm/tom-select@2.1.0/dist/js/tom-select.complete.min.js"></script>

	<!-- Swiper JS -->
	<script src="assets/swiper/swiper-bundle.min.js" defer></script>

	<!-- JS -->
	<script type="text/javascript" src="assets/js/calender.js" defer></script>
	<script type="text/javascript" src="assets/js/my-account-script.js" defer></script>
	<script type="text/javascript" src="assets/js/script.js" defer></script>
</body>
</html>
